@@ -1,9 +1,10 @@
 """
-Idempotent API for managing system settings
+System settings
+===============
 """
 from __future__ import with_statement
 
-from fabric.api import sudo
+from fabric.api import sudo, warn
 from fabric.contrib.files import append
 
 from fabtools.files import watch
@@ -16,7 +17,7 @@ from fabtools.system import (
 
 def sysctl(key, value, persist=True):
     """
-    Require a kernel parameter to have a specific value
+    Require a kernel parameter to have a specific value.
     """
     if get_sysctl(key) != value:
         set_sysctl(key, value)
@@ -24,17 +25,17 @@ def sysctl(key, value, persist=True):
     if persist:
         from fabtools import require
         filename = '/etc/sysctl.d/60-%s.conf' % key
-        def on_change():
-            sudo('service procps start')
-        with watch(filename, True, on_change):
+        with watch(filename, use_sudo=True) as config:
             require.file(filename,
                 contents='%(key)s = %(value)s\n' % locals(),
                 use_sudo=True)
+        if config.changed:
+            sudo('service procps start')
 
 
 def hostname(name):
     """
-    Require the hostname to have a specific value
+    Require the hostname to have a specific value.
     """
     if get_hostname() != name:
         set_hostname(name)
@@ -42,16 +43,13 @@ def hostname(name):
 
 def locales(names):
     """
-    Require the list of locales to be available
+    Require the list of locales to be available.
     """
 
     config_file = '/var/lib/locales/supported.d/local'
 
-    def regenerate():
-        sudo('dpkg-reconfigure locales')
-
     # Regenerate locales if config file changes
-    with watch(config_file, True, regenerate):
+    with watch(config_file, use_sudo=True) as config:
 
         # Add valid locale names to the config file
         supported = dict(supported_locales())
@@ -63,17 +61,20 @@ def locales(names):
             else:
                 warn('Unsupported locale name "%s"' % name)
 
+    if config.changed:
+        sudo('dpkg-reconfigure locales')
+
 
 def locale(name):
     """
-    Require the locale to be available
+    Require the locale to be available.
     """
     locales([name])
 
 
 def default_locale(name):
     """
-    Require the locale to be the default
+    Require the locale to be the default.
     """
     from fabtools import require
 
