@@ -1,5 +1,6 @@
 """
-Idempotent API for managing users
+System users
+============
 """
 from fabtools.files import is_file
 from fabtools.user import *
@@ -9,7 +10,18 @@ import fabtools.require
 
 def user(name, home=None):
     """
-    Require a user
+    Require a user.
+
+    ::
+
+        from fabtools import require
+
+        require.user('alice')                   # no home directory
+        require.user('bob', home='/home/bob')
+
+    .. note:: this function can be accessed directly from the
+              ``fabtools.require`` module for convenience.
+
     """
     if not exists(name):
         create(name, home=home)
@@ -19,7 +31,11 @@ def user(name, home=None):
 
 def sudoer(username, hosts="ALL", operators="ALL", passwd=False, commands="ALL"):
     """
-    Require sudo permissions for a given user
+    Require sudo permissions for a given user.
+
+    .. note:: this function can be accessed directly from the
+              ``fabtools.require`` module for convenience.
+
     """
     tags = "PASSWD:" if passwd else "NOPASSWD:"
     spec = "%(username)s %(hosts)s=(%(operators)s) %(tags)s %(commands)s" % locals()
